EncodeError

Enum EncodeError 

pub enum EncodeError {
    BufferTooSmall {
        required: usize,
        available: usize,
    },
    PduTooLarge {
        length: usize,
        maximum: usize,
    },
    QuantityOutOfRange {
        quantity: u16,
    },
    ByteCountMismatch {
        declared: usize,
        actual: usize,
    },
    ByteCountOutOfRange {
        count: usize,
        minimum: usize,
        maximum: usize,
    },
    InvalidReferenceType(u8),
    InvalidFileRecordLength {
        length: usize,
    },
    FileRecordOutOfRange {
        file_number: u16,
        record_number: u16,
        record_length: u16,
    },
    InvalidDiagnosticDataLength {
        length: usize,
    },
}
Errors that can occur when encoding a Modbus PDU.

Variants



BufferTooSmall

Provided buffer is too small.

Fields

required: usize

Required buffer size.

available: usize

Available buffer size.



PduTooLarge

Encoded PDU would exceed the Modbus maximum of 253 bytes.

Fields

length: usize

Encoded PDU length.

maximum: usize

Maximum allowed PDU length.



QuantityOutOfRange

Quantity exceeds protocol limits.

Fields

quantity: u16

The invalid quantity value.



ByteCountMismatch

Declared byte count does not match the payload length.

Fields

declared: usize

Declared byte count.

actual: usize

Actual payload length.



ByteCountOutOfRange

Byte count is outside the allowed range for this function code.

Fields

count: usize

The invalid byte count.

minimum: usize

The minimum allowed byte count.

maximum: usize

The maximum allowed byte count.



InvalidReferenceType(u8)

File sub-request reference type is not 6.



InvalidFileRecordLength

Packed file-record data cannot be split into valid sub-record groups.

Fields

length: usize

Invalid packed file-record byte length.



FileRecordOutOfRange

File-record address fields are outside the Modbus file-record model.

Fields

file_number: u16

File number.

record_number: u16

Starting record number.

record_length: u16

Number of records.



InvalidDiagnosticDataLength

Diagnostics data is not an even number of bytes.

Fields

length: usize

Invalid diagnostics data length.