pub enum EncodeError {
BufferTooSmall {
required: usize,
available: usize,
},
PduTooLarge {
length: usize,
maximum: usize,
},
QuantityOutOfRange {
quantity: u16,
},
ByteCountMismatch {
declared: usize,
actual: usize,
},
ByteCountOutOfRange {
count: usize,
minimum: usize,
maximum: usize,
},
InvalidReferenceType(u8),
InvalidFileRecordLength {
length: usize,
},
FileRecordOutOfRange {
file_number: u16,
record_number: u16,
record_length: u16,
},
InvalidDiagnosticDataLength {
length: usize,
},
}Expand description
Errors that can occur when encoding a Modbus PDU.
Variants
BufferTooSmall
Provided buffer is too small.
PduTooLarge
Encoded PDU would exceed the Modbus maximum of 253 bytes.
QuantityOutOfRange
Quantity exceeds protocol limits.
ByteCountMismatch
Declared byte count does not match the payload length.
ByteCountOutOfRange
Byte count is outside the allowed range for this function code.
Fields
InvalidReferenceType(u8)
File sub-request reference type is not 6.
InvalidFileRecordLength
Packed file-record data cannot be split into valid sub-record groups.
FileRecordOutOfRange
File-record address fields are outside the Modbus file-record model.
Fields
InvalidDiagnosticDataLength
Diagnostics data is not an even number of bytes.